# xhamza

A powerful, lightweight command-line tool and Python library to extract raw `.m3u8` (HLS stream)  direct links from Xhamster, simply paste video url from browser tab.

## Installation

You can install `xhamza` directly from PyPI:

```bash
pip install xhamza
